Enumeration
QmiGasFirmwareAutoSimMode
since: 1.36
Members
QMI_GAS_FIRMWARE_AUTO_SIM_DISABLE-
Disable the automatic carrier switch according to the SIM.
- Value:
0 - Nickname:
disable - Available since: 1.36
- Value:
QMI_GAS_FIRMWARE_AUTO_SIM_ENABLE-
Enable the automatic carrier switch according to the SIM.
- Value:
1 - Nickname:
enable - Available since: 1.36
- Value:
QMI_GAS_FIRMWARE_AUTO_SIM_ENABLE_ONE_SHOT-
Enable the automatic carrier switch according to the SIM just for one time.
- Value:
2 - Nickname:
enable-one-shot - Available since: 1.36
- Value:
QMI_GAS_FIRMWARE_AUTO_SIM_PENDING_ONE_SHOT-
Indicate the pending status of a single switch (used only in DMS Get Firmware Auto Sim).
- Value:
3 - Nickname:
pending-one-shot - Available since: 1.36
- Value:
Type functions
qmi_gas_firmware_auto_sim_mode_get_string
Gets the nickname string for the QmiGasFirmwareAutoSimMode specified at val.
since: 1.36