Enumeration

QmiLocTimeSource

since: 1.22

Declaration

enum Qmi.LocTimeSource

Description [src]

Source of the used time.

Available since: 1.22

Members

QMI_LOC_TIME_SOURCE_INVALID

Invalid.

  • Value: 0
  • Nickname: invalid
  • Available since: 1.22
QMI_LOC_TIME_SOURCE_NETWORK_TIME_TRANSFER

Time is set by the 1X system.

  • Value: 1
  • Nickname: network-time-transfer
  • Available since: 1.22
QMI_LOC_TIME_SOURCE_NETWORK_TIME_TAGGING

Time is set by WCDMA/GSM time tagging.

  • Value: 2
  • Nickname: network-time-tagging
  • Available since: 1.22
QMI_LOC_TIME_SOURCE_EXTERNAL_INPUT

Time set by external injection.

  • Value: 3
  • Nickname: external-input
  • Available since: 1.22
QMI_LOC_TIME_SOURCE_TOW_DECODE

Time is set after decoding over-the-air GPS navigation data from one GPS satellite.

  • Value: 4
  • Nickname: tow-decode
  • Available since: 1.22
QMI_LOC_TIME_SOURCE_TOW_CONFIRMED

Time is set after decoding over-the-air GPS navigation data from multiple satellites.

  • Value: 5
  • Nickname: tow-confirmed
  • Available since: 1.22
QMI_LOC_TIME_SOURCE_TOW_AND_WEEK_CONFIRMED

Both time of the week and GPS week number are known.

  • Value: 6
  • Nickname: tow-and-week-confirmed
  • Available since: 1.22
QMI_LOC_TIME_SOURCE_NAVIGATION_SOLUTION

Time is set by the position engine after the fix is obtained.

  • Value: 7
  • Nickname: navigation-solution
  • Available since: 1.22
QMI_LOC_TIME_SOURCE_SOLVE_FOR_TIME

Time is set by the position engine after performing SFT.

  • Value: 8
  • Nickname: solve-for-time
  • Available since: 1.22
QMI_LOC_TIME_SOURCE_GLO_TOW_DECODE

Time is set after decoding QZSS satellites.

  • Value: 9
  • Nickname: glo-tow-decode
  • Available since: 1.22
QMI_LOC_TIME_SOURCE_TIME_TRANSFORM

Time is set after transforming the GPS to GLO time.

  • Value: 10
  • Nickname: time-transform
  • Available since: 1.22
QMI_LOC_TIME_SOURCE_WCDMA_SLEEP_TIME_TAG

Time is set by the sleep time tag provided by the WCDMA network.

  • Value: 11
  • Nickname: wcdma-sleep-time-tag
  • Available since: 1.22
QMI_LOC_TIME_SOURCE_GSM_SLEEP_TIME_TAG

Time is set by the sleep time tag provided by the GSM network.

  • Value: 12
  • Nickname: gsm-sleep-time-tag
  • Available since: 1.22
QMI_LOC_TIME_SOURCE_UNKNOWN

Unknown.

  • Value: 13
  • Nickname: unknown
  • Available since: 1.22
QMI_LOC_TIME_SOURCE_SYSTEM_TIMETICK

Time is derived from the system clock.

  • Value: 14
  • Nickname: system-timetick
  • Available since: 1.22
QMI_LOC_TIME_SOURCE_QZSS_TOW_DECODE

Time set after decoding QZSS satellites.

  • Value: 15
  • Nickname: qzss-tow-decode
  • Available since: 1.22
QMI_LOC_TIME_SOURCE_BDS_TOW_DECODE

Time set after decoding BDS satellites.

  • Value: 16
  • Nickname: bds-tow-decode
  • Available since: 1.22

Type functions

qmi_loc_time_source_get_string

Gets the nickname string for the QmiLocTimeSource specified at val.

since: 1.22