Enumeration
QmiWmsCdmaErrorClass
since: 1.0
Description [src]
Error class reported from the network when failed to send an SMS in CDMA, or reported by the device when failed to process a transfer-only CDMA message.
Available since: 1.0
Members
QMI_WMS_CDMA_ERROR_CLASS_TEMPORARY-
Temporary error reported by network.
- Value:
0 - Nickname:
temporary - Available since: 1.0
- Value:
QMI_WMS_CDMA_ERROR_CLASS_PERMANENT-
Permanent error reported by network.
- Value:
1 - Nickname:
permanent - Available since: 1.0
- Value:
QMI_WMS_CDMA_ERROR_CLASS_TEMPORARY_DEVICE-
Temporary error reported by device. Since 1.28.
- Value:
2 - Nickname:
temporary-device - Available since: 1.0
- Value:
QMI_WMS_CDMA_ERROR_CLASS_PERMANENT_DEVICE-
Permanent error reported by device. Since 1.28.
- Value:
3 - Nickname:
permanent-device - Available since: 1.0
- Value:
Type functions
qmi_wms_cdma_error_class_get_string
Gets the nickname string for the QmiWmsCdmaErrorClass specified at val.
since: 1.0